@@ -18,7 +18,6 @@
 #' @param ... Comma separated list of unquoted expressions.
 #'            Uses dplyr's \code{select} to select
 #'            columns from data.
-#' @param .dots Use assert_() to select columns using standard evaluation.
 #' @param success_fun Function to call if assertion passes. Defaults to
 #'                    returning \code{data}.
 #' @param error_fun Function to call if assertion fails. Defaults to printing
@@ -39,18 +38,9 @@
 #' # returns mtcars
 #' assert(mtcars, not_na, vs)
 #'
-#' # equivalent statements using standard evaluation
-#' assert_(mtcars, not_na, "vs")
-#' var <- "vs"
-#' assert_(mtcars, not_na, var)
-#'
 #' # return mtcars
 #' assert(mtcars, not_na, mpg:carb)
 #'
-#' # equivalent using standard evaluation
-#' assert_(mtcars, not_na, "mpg:carb")
-#'
-#'
 #' library(magrittr)                    # for piping operator
 #'
 #' mtcars %>%
@@ -65,17 +55,9 @@
 #'
 #' @export
 assert <- function(data, predicate, ..., success_fun=success_continue,
-                   error_fun=error_stop){
-  assert_(data, predicate, .dots = lazyeval::lazy_dots(...),
-          success_fun=success_fun,
-          error_fun = error_fun)
-}
-
-#' @export
-#' @rdname assert
-assert_ <- function(data, predicate, ..., .dots, success_fun=success_continue,
                       error_fun=error_stop){
-  sub.frame <- dplyr::select_(data, ..., .dots = .dots)
+  keeper.vars <- dplyr::quos(...)
+  sub.frame <- dplyr::select(data, rlang::UQS(keeper.vars))
   name.of.predicate <- lazyeval::expr_text(predicate)
   if(!is.null(attr(predicate, "call"))){
     name.of.predicate <- attr(predicate, "call")
@@ -116,7 +98,8 @@ assert_ <- function(data, predicate, ..., .dots, success_fun=success_continue,
       return(NULL)
     index.of.violations <- which(!col)
     offending.elements <- sub.frame[[col.name]][index.of.violations]
-    an_error <- make.assertr.assert.error(name.of.predicate,
+    an_error <- make.assertr.assert.error("assert",
+                                          name.of.predicate,
                                           col.name,
                                           num.violations,
                                           index.of.violations,
@@ -149,7 +132,6 @@ assert_ <- function(data, predicate, ..., .dots, success_fun=success_continue,
 #' @param ... Comma separated list of unquoted expressions.
 #'            Uses dplyr's \code{select} to select
 #'            columns from data.
-#' @param .dots Use assert_rows_() to select columns using standard evaluation.
 #' @param success_fun Function to call if assertion passes. Defaults to
 #'                    returning \code{data}.
 #' @param error_fun Function to call if assertion fails. Defaults to printing
@@ -171,10 +153,6 @@ assert_ <- function(data, predicate, ..., .dots, success_fun=success_continue,
 #' # returns mtcars
 #' assert_rows(mtcars, num_row_NAs, within_bounds(0,2), mpg:carb)
 #'
-#' # equivalent using standard evaluation
-#' assert_rows_(mtcars, num_row_NAs, within_bounds(0,2), "mpg:carb")
-#'
-#'
 #' library(magrittr)                    # for piping operator
 #'
 #' mtcars %>%
@@ -190,20 +168,10 @@ assert_ <- function(data, predicate, ..., .dots, success_fun=success_continue,
 #' @export
 #'
 assert_rows <- function(data, row_reduction_fn, predicate, ...,
-                        success_fun=success_continue,
-                        error_fun=error_stop){
-  assert_rows_(data, row_reduction_fn, predicate,
-               .dots = lazyeval::lazy_dots(...),
-               success_fun = success_fun,
-               error_fun = error_fun)
-}
-
-#' @export
-#' @rdname assert_rows
-assert_rows_ <- function(data, row_reduction_fn, predicate, ..., .dots,
                          success_fun=success_continue,
                          error_fun=error_stop){
-  sub.frame <- dplyr::select_(data, ..., .dots = .dots)
+  keeper.vars <- dplyr::quos(...)
+  sub.frame <- dplyr::select(data, rlang::UQS(keeper.vars))
   name.of.row.redux.fn <- lazyeval::expr_text(row_reduction_fn)
   name.of.predicate <- lazyeval::expr_text(predicate)
   if(!is.null(attr(row_reduction_fn, "call"))){
@@ -244,11 +212,15 @@ assert_rows_ <- function(data, row_reduction_fn, predicate, ..., .dots,
     # NOT calling either function would break the pipeline.
     return(error_fun(list(), data=data))
   loc.violations <- which(!log.vec)
+  offending.elements <- redux[!log.vec]
 
-  error <- make.assertr.assert_rows.error(name.of.row.redux.fn,
+  error <- make.assertr.assert_rows.error("assert_rows",
+                                          name.of.row.redux.fn,
                                           name.of.predicate,
+                                          as.character(keeper.vars),
                                           num.violations,
-                                          loc.violations)
+                                          loc.violations,
+                                          offending.elements)
   error_fun(list(error), data=data)
 
 }
@@ -273,7 +245,6 @@ assert_rows_ <- function(data, row_reduction_fn, predicate, ..., .dots,
 #' @param ... Comma separated list of unquoted expressions.
 #'            Uses dplyr's \code{select} to select
 #'            columns from data.
-#' @param .dots Use insist_() to select columns using standard evaluation.
 #' @param success_fun Function to call if assertion passes. Defaults to
 #'                    returning \code{data}.
 #' @param error_fun Function to call if assertion fails. Defaults to printing
@@ -293,9 +264,6 @@ assert_rows_ <- function(data, row_reduction_fn, predicate, ..., .dots,
 #'
 #' insist(iris, within_n_sds(3), Sepal.Length)   # returns iris
 #'
-#' # equivalent using standard evaluation
-#' insist_(iris, within_n_sds(3), "Sepal.Length")
-#'
 #' library(magrittr)
 #'
 #' iris %>%
@@ -312,19 +280,10 @@ assert_rows_ <- function(data, row_reduction_fn, predicate, ..., .dots,
 #'
 #' @export
 insist <- function(data, predicate_generator, ...,
-                   success_fun=success_continue,
-                   error_fun=error_stop){
-  insist_(data, predicate_generator, .dots = lazyeval::lazy_dots(...),
-          success_fun=success_fun,
-          error_fun = error_fun)
-}
-
-#' @export
-#' @rdname insist
-insist_ <- function(data, predicate_generator, ..., .dots,
                     success_fun=success_continue,
                     error_fun=error_stop){
-  sub.frame <- dplyr::select_(data, ..., .dots = .dots)
+  keeper.vars <- dplyr::quos(...)
+  sub.frame <- dplyr::select(data, rlang::UQS(keeper.vars))
   name.of.predicate.generator <- lazyeval::expr_text(predicate_generator)
   if(!is.null(attr(predicate_generator, "call"))){
     name.of.predicate.generator <- attr(predicate_generator, "call")
@@ -365,7 +324,8 @@ insist_ <- function(data, predicate_generator, ..., .dots,
       return(NULL)
     index.of.violations <- which(!col)
     offending.elements <- sub.frame[[col.name]][index.of.violations]
-    an_error <- make.assertr.assert.error(name.of.predicate.generator,
+    an_error <- make.assertr.assert.error("insist",
+                                          name.of.predicate.generator,
                                           col.name,
                                           num.violations,
                                           index.of.violations,
@@ -404,7 +364,6 @@ insist_ <- function(data, predicate_generator, ..., .dots,
 #' @param ... Comma separated list of unquoted expressions.
 #'            Uses dplyr's \code{select} to select
 #'            columns from data.
-#' @param .dots Use insist_rows_() to select columns using standard evaluation.
 #' @param success_fun Function to call if assertion passes. Defaults to
 #'                    returning \code{data}.
 #' @param error_fun Function to call if assertion fails. Defaults to printing
@@ -425,10 +384,6 @@ insist_ <- function(data, predicate_generator, ..., .dots,
 #' # returns mtcars
 #' insist_rows(mtcars, maha_dist, within_n_mads(30), mpg:carb)
 #'
-#' # equivalent using standard evaluation
-#' insist_rows_(mtcars, maha_dist, within_n_mads(30), "mpg:carb")
-#'
-#'
 #' library(magrittr)                    # for piping operator
 #'
 #' mtcars %>%
@@ -444,21 +399,10 @@ insist_ <- function(data, predicate_generator, ..., .dots,
 #' @export
 #'
 insist_rows <- function(data, row_reduction_fn, predicate_generator, ...,
-                        success_fun=success_continue,
-                        error_fun=error_stop){
-  insist_rows_(data, row_reduction_fn, predicate_generator,
-               .dots = lazyeval::lazy_dots(...),
-               success_fun=success_fun, error_fun = error_fun)
-}
-
-#' @export
-#' @rdname insist_rows
-insist_rows_ <- function(data, row_reduction_fn, predicate_generator, ...,
-                         .dots, success_fun=success_continue,
+                         success_fun=success_continue,
                          error_fun=error_stop){
-  sub.frame <- dplyr::select_(data, ..., .dots = .dots)
-
-
+  keeper.vars <- dplyr::quos(...)
+  sub.frame <- dplyr::select(data, rlang::UQS(keeper.vars))
   name.of.row.redux.fn <- lazyeval::expr_text(row_reduction_fn)
   name.of.predicate.generator <- lazyeval::expr_text(predicate_generator)
   if(!is.null(attr(row_reduction_fn, "call"))){
@@ -498,11 +442,15 @@ insist_rows_ <- function(data, row_reduction_fn, predicate_generator, ...,
     # NOT calling either function would break the pipeline.
     return(error_fun(list(), data=data))
   loc.violations <- which(!log.vec)
+  offending.elements <- redux[!log.vec]
 
-  error <- make.assertr.assert_rows.error(name.of.row.redux.fn,
+  error <- make.assertr.assert_rows.error("insist_rows",
+                                          name.of.row.redux.fn,
                                           name.of.predicate.generator,
+                                          as.character(keeper.vars),
                                           num.violations,
-                                          loc.violations)
+                                          loc.violations,
+                                          offending.elements)
   error_fun(list(error), data=data)
 }
 
@@ -571,6 +519,8 @@ verify <- function(data, expr, success_fun=success_continue,
   envir <- data
   enclos <- parent.frame()
   logical.results <- eval(expr, envir, enclos)
+  # NAs are very likely errors, and cause problems in the all() below.
+  logical.results <- ifelse(is.na(logical.results), FALSE, logical.results)
 
   success_fun_override <- attr(data, "assertr_in_chain_success_fun_override")
   if(!is.null(success_fun_override)){
@@ -590,6 +540,9 @@ verify <- function(data, expr, success_fun=success_continue,
     return(success_fun(data))
   num.violations <- sum(!logical.results)
   if(num.violations==0) return(error_fun(list(), data=data))
-  error <- make.assertr.verify.error(num.violations, deparse(expr))
+  error <- make.assertr.verify.error("verify",
+                                     num.violations, deparse(expr),
+                                     (1:length(logical.results))[!logical.results])
   error_fun(list(error), data=data)
 }
+
